aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--engines/saga/animation.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/engines/saga/animation.cpp b/engines/saga/animation.cpp
index 88caec96c9..d254c69078 100644
--- a/engines/saga/animation.cpp
+++ b/engines/saga/animation.cpp
@@ -363,10 +363,11 @@ void Anim::play(uint16 animId, int vectorTime, bool playing) {
return;
}
// HACK: the animation starts playing before sfwaitframes is called in IHNM, which
// causes the game to wait forever. Raise the framecount by 10 to avoid lockup
// TODO: remove this hack
- _vm->_frameCount += 10;
+ if (_vm->_interface->getMode() == kPanelVideo)
+ _vm->_frameCount += 10;
if (anim->completed < anim->cycles) {
frame = anim->currentFrame;
@@ -363,10 +363,11 @@ void Anim::play(uint16 animId, int vectorTime, bool playing) {
return;
}
- // HACK: the animation starts playing before sfwaitframes is called in IHNM, which
- // causes the game to wait forever. Raise the framecount by 10 to avoid lockup
+ // HACK: When a video is played in IHNM, the animation starts playing before sfwaitframes
+ // is called, which causes the game to wait forever. Raise the framecount by 10 to avoid lockup
// TODO: remove this hack